<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/AboutDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <location filename="../src/AlbumView.cpp" line="10"/>
        <source>Browse Album</source>
        <translation>Album anzeigen</translation>
    </message>
    <message>
        <location filename="../src/AlbumView.cpp" line="12"/>
        <location filename="../src/AlbumView.cpp" line="53"/>
        <source>Album Review</source>
        <translatorcomment>Not fully sure what Germans say.</translatorcomment>
        <translation>Album Überblick</translation>
    </message>
    <message>
        <location filename="../src/AlbumView.cpp" line="102"/>
        <location filename="../src/AlbumView.cpp" line="104"/>
        <source>Fetching of album details failed!</source>
        <translation>Herunterladen von Album Informationen ist fehlgeschlagen!</translation>
    </message>
    <message>
        <location filename="../src/AlbumView.cpp" line="141"/>
        <location filename="../src/AlbumView.cpp" line="143"/>
        <source>Fetching of album details failed: </source>
        <translation>Herunterladen von Album Informationen ist fehlgeschlagen: </translation>
    </message>
</context>
<context>
    <name>ArtistView</name>
    <message>
        <location filename="../src/artistview.cpp" line="12"/>
        <source>Browse Artist</source>
        <translation>Interpreten anzeigen</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="14"/>
        <source>Artist Biography</source>
        <translation>Künstler Biografie</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="44"/>
        <source>Biography</source>
        <translation>Biografie</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="82"/>
        <location filename="../src/artistview.cpp" line="84"/>
        <source>Fetching of artist details failed!</source>
        <translation>Herunterladen von Küunstler Informationen ist fehlgeschlagen!</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="92"/>
        <location filename="../src/artistview.cpp" line="95"/>
        <source>Loading </source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../src/artistview.cpp" line="117"/>
        <location filename="../src/artistview.cpp" line="119"/>
        <source>Fetching of artist details failed: </source>
        <translation>Herunterladen von Küunstler Informationen ist fehlgeschlagen: </translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../src/logindialog.cpp" line="13"/>
        <source>QSpot - Login</source>
        <translation>QSpot - Anmeldung</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="16"/>
        <source>UserID:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="18"/>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Remember UserID and password</source>
        <translation type="obsolete">Benutzernamen und Passwort speichern</translation>
    </message>
    <message>
        <source>Low bitrate (96kbps)</source>
        <translation type="obsolete">Niedriege Bit Rate (96kb/s)</translation>
    </message>
    <message>
        <source>Standard bitrate (160kbps)</source>
        <translation type="obsolete">Standard Bit Rate (160kb/s)</translation>
    </message>
    <message>
        <source>High bitrate (320kbps)</source>
        <translation type="obsolete">Hohe Bit Rate (320kb/s)</translation>
    </message>
    <message>
        <source>Preferred bitrate</source>
        <translation type="obsolete">Bevorzugte Bit Rate</translation>
    </message>
    <message>
        <location filename="../src/logindialog.cpp" line="21"/>
        <source>Login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Remember UserID &amp;&amp; Pwd</source>
        <translation type="obsolete">Benutzer &amp; Passwort speichern</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="16"/>
        <source>QSpot - Playlists</source>
        <translation>QSpot - Playlisten</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="67"/>
        <location filename="../src/MainWindow.cpp" line="721"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="69"/>
        <location filename="../src/MainWindow.cpp" line="727"/>
        <source>FM Transmitter</source>
        <translation>FM Transmitter</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="71"/>
        <location filename="../src/MainWindow.cpp" line="731"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="239"/>
        <location filename="../src/MainWindow.cpp" line="241"/>
        <source>Logging in to Spotify</source>
        <translation>Anmeldung bei Spotify</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="266"/>
        <source>About QSpot</source>
        <translation>Über QSpot</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="268"/>
        <source>QSpot version </source>
        <translation>QSpot Version</translation>
    </message>
    <message>
        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).

(C) 2011 Andreas Enbacka and The QSpot Team.

Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo) for the Finnish translations.</source>
        <translation type="obsolete">Ein open-source Qt-basierter Spotify client fuer das N900/Maemo5 (basierend auf libopenspotify).

(C) 2011 Andreas Enbacka und das QSpot Team.

Besonderen Dank an Markus (markusm@tmo) für Hilfe mit dem graphischem layout und Tomi (rantom@tmo) für die Finnische Übersetzung.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="214"/>
        <location filename="../src/MainWindow.cpp" line="224"/>
        <location filename="../src/MainWindow.cpp" line="524"/>
        <source>Error:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="224"/>
        <source>No suitable internet access point(s) found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="268"/>
        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).

(C) 2011 Andreas Enbacka and The QSpot Team.

Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) for the translations.</source>
        <translation>Ein open-source Qt-basierter Spotify client fuer das N900/Maemo5 (basierend auf libopenspotify).

(C) 2011 Andreas Enbacka und das QSpot Team.

Besonderen Dank an Markus (markusm@tmo) für Hilfe mit dem graphischem layout und Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) für die Übersetzungen.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="544"/>
        <location filename="../src/MainWindow.cpp" line="546"/>
        <source>Loading playlists</source>
        <translation>Laden der Playlists</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="570"/>
        <location filename="../src/MainWindow.cpp" line="573"/>
        <source>Timeout occured while loading playlists!</source>
        <translation>Timeout beim laden der Playlists überschritten!</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="603"/>
        <source>tracks</source>
        <translation>Lieder</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="754"/>
        <location filename="../src/MainWindow.cpp" line="757"/>
        <source>Searching</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="763"/>
        <location filename="../src/MainWindow.cpp" line="766"/>
        <location filename="../src/MainWindow.cpp" line="782"/>
        <location filename="../src/MainWindow.cpp" line="784"/>
        <source>Error: </source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="805"/>
        <location filename="../src/MainWindow.cpp" line="807"/>
        <source>No tracks found!</source>
        <translation>Keine Titel gefunden!</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="825"/>
        <location filename="../src/MainWindow.cpp" line="827"/>
        <source>Playback paused due to the same account being used somewhere else!</source>
        <translation>Wiedergabe pausiert da das gleiche Account wo anders genutzt wird!</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="840"/>
        <location filename="../src/MainWindow.cpp" line="842"/>
        <source>Last.fm error: </source>
        <translation>Last.fm Fehler:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="940"/>
        <location filename="../src/MainWindow.cpp" line="942"/>
        <source>Failed to re-authenticate with Spotify</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QueueView</name>
    <message>
        <location filename="../src/QueueView.cpp" line="15"/>
        <location filename="../src/QueueView.cpp" line="915"/>
        <location filename="../src/QueueView.cpp" line="924"/>
        <location filename="../src/QueueView.cpp" line="1084"/>
        <source>Now Playing</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="181"/>
        <source>Play Album</source>
        <translation>Album wiedergeben</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="184"/>
        <source>Browse Album</source>
        <translation>Album durchsuchen</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="187"/>
        <source>Browse Artist</source>
        <translation>Künstler durchsuchen</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="202"/>
        <location filename="../src/QueueView.cpp" line="210"/>
        <source>FM Transmitter</source>
        <translation>FM Transmitter</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="395"/>
        <location filename="../src/QueueView.cpp" line="397"/>
        <location filename="../src/QueueView.cpp" line="542"/>
        <location filename="../src/QueueView.cpp" line="544"/>
        <location filename="../src/QueueView.cpp" line="852"/>
        <location filename="../src/QueueView.cpp" line="854"/>
        <location filename="../src/QueueView.cpp" line="875"/>
        <location filename="../src/QueueView.cpp" line="877"/>
        <source>Error starting track playback: </source>
        <translation>Fehler beim starten der Wiedergabe: </translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="533"/>
        <location filename="../src/QueueView.cpp" line="535"/>
        <source>Buffering</source>
        <translation>Puffern</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="924"/>
        <location filename="../src/QueueView.cpp" line="928"/>
        <location filename="../src/QueueView.cpp" line="1084"/>
        <location filename="../src/QueueView.cpp" line="1117"/>
        <source>Shuffle</source>
        <translatorcomment>Not sure about this one.</translatorcomment>
        <translation>Durcheinander</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="990"/>
        <location filename="../src/QueueView.cpp" line="993"/>
        <source>Loading album tracks</source>
        <translation>Laden der Album Titel</translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="1016"/>
        <location filename="../src/QueueView.cpp" line="1018"/>
        <source>Fetching of album tracks failed: </source>
        <translation>Laden der Album Titel fehlgeschlagen: </translation>
    </message>
    <message>
        <location filename="../src/QueueView.cpp" line="1027"/>
        <location filename="../src/QueueView.cpp" line="1029"/>
        <source>Failed to load tracks!</source>
        <translation>Laden der Titel fehlgeschlagen!</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="191"/>
        <location filename="../src/SettingsDialog.cpp" line="219"/>
        <source>Remember UserID and password</source>
        <translation>Benutzernamen und Passwort speichern</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="49"/>
        <source>Low bitrate (96kbps)</source>
        <translation>Niedriege Bit Rate (96kb/s)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="49"/>
        <source>Standard bitrate (160kbps)</source>
        <translation>Standard Bit Rate (160kb/s)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="50"/>
        <source>High bitrate (320kbps)</source>
        <translation>Hohe Bit Rate (320kb/s)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="169"/>
        <location filename="../src/SettingsDialog.cpp" line="198"/>
        <source>QSpot - Settings</source>
        <translation>QSpot - Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="170"/>
        <source>Max. tracks returned</source>
        <translation>Max. Lieder laden</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="171"/>
        <source>Max. albums returned</source>
        <translation>Max. Alben laden</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="172"/>
        <source>Max. artists returned</source>
        <translation>Max. Künstler laden</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="173"/>
        <location filename="../src/SettingsDialog.cpp" line="202"/>
        <source>Search settings</source>
        <translation>Such Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="174"/>
        <location filename="../src/SettingsDialog.cpp" line="203"/>
        <source>Buffering settings</source>
        <translation>Puffer Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="175"/>
        <source>Min. buffering length (secs)</source>
        <translation>Min. Puffer Dauer (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="176"/>
        <source>Enable track pre-buffering</source>
        <translation>Titel vor-puffern aktivieren</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="178"/>
        <location filename="../src/SettingsDialog.cpp" line="207"/>
        <source>Preferred bitrate</source>
        <translation>Bevorzugte Bit Rate</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="179"/>
        <location filename="../src/SettingsDialog.cpp" line="208"/>
        <source>UI Language</source>
        <translation>UI Sprache</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="180"/>
        <location filename="../src/SettingsDialog.cpp" line="209"/>
        <source>Display orientation</source>
        <translation>Display Orientierung</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="182"/>
        <location filename="../src/SettingsDialog.cpp" line="211"/>
        <source>Playlist options</source>
        <translation>Playlisten Optionen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="183"/>
        <source>Playlist load timeout (secs)</source>
        <translation>Playlisten Lade-Timeout (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="184"/>
        <location filename="../src/SettingsDialog.cpp" line="213"/>
        <source>Pause on headset unplugged</source>
        <translation>Pausieren wenn Headset ausgestöpselt wird</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="185"/>
        <location filename="../src/SettingsDialog.cpp" line="214"/>
        <source>Scrobbling options</source>
        <translation>Scrobbling Optionen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="186"/>
        <source>Enable scrobbling to Last.fm</source>
        <translation>Last.fm scrobbling aktivieren</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="187"/>
        <location filename="../src/SettingsDialog.cpp" line="216"/>
        <source>Last.fm username</source>
        <translation>Last.fm Benutzername</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="188"/>
        <location filename="../src/SettingsDialog.cpp" line="217"/>
        <source>Last.fm password</source>
        <translation>Last.fm Passwort</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="189"/>
        <location filename="../src/SettingsDialog.cpp" line="218"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="190"/>
        <location filename="../src/SettingsDialog.cpp" line="220"/>
        <source>Hide coverart in Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="199"/>
        <source>Max. tracks</source>
        <translation>Max. Titel</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="200"/>
        <source>Max. albums</source>
        <translation>Max. Alben</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="201"/>
        <source>Max. artists</source>
        <translation>Max. Künstler</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="204"/>
        <source>Min.buff.length (secs)</source>
        <translation>Min.Puffer Länge (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="205"/>
        <source>Enable track pre-buff.</source>
        <translation>Titel vor-puffern akt.</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="212"/>
        <source>Playlist load TO (secs)</source>
        <translation>Playlisten Lade-TO (sek.)</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="215"/>
        <source>Enable Last.fm scrobbling</source>
        <translation>Last.fm scrob. aktivieren</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="405"/>
        <location filename="../src/SettingsDialog.cpp" line="407"/>
        <source>Please restart QSpot for bitrate change to take effect!</source>
        <translation>Bitte starten Sie QSpot neu um den Bit Raten wechsel anzuwenden!</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="421"/>
        <location filename="../src/SettingsDialog.cpp" line="423"/>
        <source>Please restart QSpot for language change to take effect!</source>
        <translation>Bitte starten Sie QSpot neu um den Sprachwechsel anzuwenden!</translation>
    </message>
</context>
<context>
    <name>Spotify::Album</name>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="91"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="93"/>
        <source>Single</source>
        <translation>Single</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="95"/>
        <source>Compilation</source>
        <translation>Sammlung</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="97"/>
        <location filename="../src/qspotify_src/album.cpp" line="110"/>
        <source>Appears on</source>
        <translation>Erscheint auf</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="104"/>
        <source>Albums</source>
        <translation>Alben</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="106"/>
        <source>Singles</source>
        <translation>Singles</translation>
    </message>
    <message>
        <location filename="../src/qspotify_src/album.cpp" line="108"/>
        <source>Compilations</source>
        <translation>Sammlungen</translation>
    </message>
</context>
<context>
    <name>TrackView</name>
    <message>
        <location filename="../src/TrackView.cpp" line="54"/>
        <source>Play Album</source>
        <translation>Album wiedergeben</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="57"/>
        <source>Browse Album</source>
        <translation>Album durchsuchen</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="60"/>
        <source>Browse Artist</source>
        <translation>Künstler durchsuchen</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="71"/>
        <source>Sort tracks by</source>
        <translation>Titel Sortieren nach</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <source>Playlist order</source>
        <translation>Playlist Sortierung</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Most popular</source>
        <translation>Popularität</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Track name (ascending)</source>
        <translation>Titel Name (aufsteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Track name (descending)</source>
        <translation>Titel Name (absteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="73"/>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Artist name (ascending)</source>
        <translation>Künstler Name (aufsteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="74"/>
        <location filename="../src/TrackView.cpp" line="77"/>
        <source>Artist name (descending)</source>
        <translation>Künstler Name (absteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="74"/>
        <location filename="../src/TrackView.cpp" line="77"/>
        <source>Album name (ascending)</source>
        <translation>Album Name (aufsteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="74"/>
        <location filename="../src/TrackView.cpp" line="77"/>
        <source>Album name (descending)</source>
        <translation>Album Name (absteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="76"/>
        <source>Artist, album, track (ascending)</source>
        <translation>Künstler, Album, Titel (aufsteigend)</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="83"/>
        <location filename="../src/TrackView.cpp" line="210"/>
        <source>FM Transmitter</source>
        <translation>FM Transmitter</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="124"/>
        <location filename="../src/TrackView.cpp" line="127"/>
        <source>Loading album tracks</source>
        <translation>Laden der Album Titel</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="165"/>
        <location filename="../src/TrackView.cpp" line="167"/>
        <source>Fetching of album tracks failed: </source>
        <translation>Laden der Album Titel fehlgeschlagen: </translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="176"/>
        <location filename="../src/TrackView.cpp" line="178"/>
        <source>Failed to load tracks!</source>
        <translation>Laden der Titel fehlgeschlagen!</translation>
    </message>
    <message>
        <location filename="../src/TrackView.cpp" line="293"/>
        <source>Search results: </source>
        <translation>Such Ergebnisse: </translation>
    </message>
</context>
</TS>
